@@ -668,7 +668,7 @@ class DataTableTests(test.TestCase):
         row = self.table.get_rows()[0]
 
         self.assertEqual(35, len(row.cells['status'].data))
-        self.assertEqual(u'A Status that is longer than 35 ...',
+        self.assertEqual(u'A Status that is longer than 35 ch…',
                          row.cells['status'].data)
 
     def test_table_rendering(self):
