@@ -30,7 +30,6 @@ from cinderclient import api_versions
 from cinderclient import client as cinder_client
 from cinderclient import exceptions as cinder_exception
 from cinderclient.v2.contrib import list_extensions as cinder_list_extensions
-from six.moves import urllib
 
 from horizon import exceptions
 from horizon.utils.memoized import memoized
@@ -128,7 +127,6 @@ class VolumeBackup(BaseCinderAPIResourceWrapper):
               'created_at', 'volume_id', 'availability_zone', 'snapshot_id']
     _volume = None
     _snapshot = None
-
     @property
     def volume(self):
         return self._volume
@@ -203,111 +201,89 @@ class GroupType(base.APIResourceWrapper):
     _attrs = ['id', 'name', 'description', 'is_public', 'group_specs']
 
 
-def _find_cinder_url(request, version=None):
-    if version is None:
-        api_version = VERSIONS.get_active_version()
-        version = api_version['version']
-    version = base.Version(version)
-
-    # We support only cinder v2 and v3.
-    if version.major == 3:
-        candidates = ['volumev3', 'volume']
-    else:
-        candidates = ['volumev2', 'volume']
-
-    for service_name in candidates:
+def get_auth_params_from_request(request):
+    auth_url = base.url_for(request, 'identity')
+    cinder_urls = []
+    for service_name in ('volumev3', 'volumev2', 'volume'):
         try:
-            return version, base.url_for(request, service_name)
+            cinder_url = base.url_for(request, service_name)
+            cinder_urls.append((service_name, cinder_url))
         except exceptions.ServiceCatalogException:
             pass
-    else:
+    if not cinder_urls:
         raise exceptions.ServiceCatalogException(
-            ("Cinder %(version)s requested but no '%(service)s' service "
-             "type available in Keystone catalog.") %
-            {'version': version, 'service': candidates})
+            "no volume service configured")
+    cinder_urls = tuple(cinder_urls)  # need to make it cacheable
+    return(
+        request.user.username,
+        request.user.token.id,
+        request.user.tenant_id,
+        cinder_urls,
+        auth_url,
+    )
 
 
 @memoized
 def cinderclient(request, version=None):
-    version, cinder_url = _find_cinder_url(request, version)
-
+    if version is None:
+        api_version = VERSIONS.get_active_version()
+        version = api_version['version']
     insecure = settings.OPENSTACK_SSL_NO_VERIFY
     cacert = settings.OPENSTACK_SSL_CACERT
 
+    (username, token_id, tenant_id, cinder_urls,
+        auth_url) = get_auth_params_from_request(request)
+    version = base.Version(version)
+    if version.major == 2:
+        service_names = ('volumev2', 'volume')
+    elif version.major == 3:
+        service_names = ('volumev3', 'volume')
+    else:
+        service_names = ('volume',)
+    for name, _url in cinder_urls:
+        if name in service_names:
+            cinder_url = _url
+            break
+    else:
+        raise exceptions.ServiceCatalogException(
+            "Cinder {version} requested but no '{service}' service "
+            "type available in Keystone catalog.".format(version=version,
+                                                         service=service_names)
+        )
     c = cinder_client.Client(
         version,
-        request.user.username,
-        request.user.token.id,
-        project_id=request.user.tenant_id,
-        auth_url=base.url_for(request, 'identity'),
+        username,
+        token_id,
+        project_id=tenant_id,
+        auth_url=auth_url,
         insecure=insecure,
         cacert=cacert,
         http_log_debug=settings.DEBUG,
     )
-    c.client.auth_token = request.user.token.id
+    c.client.auth_token = token_id
     c.client.management_url = cinder_url
     return c
 
 
 def get_microversion(request, features):
-    try:
-        version, cinder_url = _find_cinder_url(request)
-    except exceptions.ServiceCatalogException:
+    for service_name in ('volume', 'volumev2', 'volumev3'):
+        try:
+            cinder_url = base.url_for(request, service_name)
+            break
+        except exceptions.ServiceCatalogException:
+            continue
+    else:
         return None
-    min_ver, max_ver = _get_server_version(request, cinder_url)
+
+    insecure = settings.OPENSTACK_SSL_NO_VERIFY
+    cacert = settings.OPENSTACK_SSL_CACERT
+
+    min_ver, max_ver = cinder_client.get_server_version(cinder_url,
+                                                        insecure, cacert)
     return microversions.get_microversion_for_features(
         'cinder', features, api_versions.APIVersion, min_ver, max_ver)
 
 
-# NOTE(amotoki): Borrowed from cinderclient.client.get_server_version()
-# to support custom SSL CA Cert support with cinderclient<5.
-def _get_server_version(request, url):
-    min_version = "2.0"
-    current_version = "2.0"
-    try:
-        u = urllib.parse.urlparse(url)
-        version_url = None
-
-        # NOTE(andreykurilin): endpoint URL has at least 2 formats:
-        #   1. The classic (legacy) endpoint:
-        #       http://{host}:{optional_port}/v{2 or 3}/{project-id}
-        #       http://{host}:{optional_port}/v{2 or 3}
-        #   3. Under wsgi:
-        #       http://{host}:{optional_port}/volume/v{2 or 3}
-        for ver in ['v2', 'v3']:
-            if u.path.endswith(ver) or "/{0}/".format(ver) in u.path:
-                path = u.path[:u.path.rfind(ver)]
-                version_url = '%s://%s%s' % (u.scheme, u.netloc, path)
-                break
-
-        if not version_url:
-            # NOTE(andreykurilin): probably, it is one of the next cases:
-            #  * https://volume.example.com/
-            #  * https://example.com/volume
-            # leave as is without cropping.
-            version_url = url
-
-        c = cinderclient(request)
-        resp, data = c.client.request(version_url, 'GET')
-
-        versions = data['versions']
-        for version in versions:
-            if '3.' in version['version']:
-                min_version = version['min_version']
-                current_version = version['version']
-                break
-            else:
-                # Set the values, but don't break out the loop here in case v3
-                # comes later
-                min_version = '2.0'
-                current_version = '2.0'
-    except cinder_exception.ClientException as e:
-        LOG.warning("Error in server version query:%s\n"
-                    "Returning APIVersion 2.0", e)
-    return (api_versions.APIVersion(min_version),
-            api_versions.APIVersion(current_version))
-
-
 def _cinderclient_with_features(request, features,
                                 raise_exc=False, message=False):
     version = get_microversion(request, features)
