@@ -149,8 +149,12 @@ def keystoneclient(request, admin=False):
     token_id = user.token.id
 
     if is_multi_domain_enabled():
-        # Cloud Admin, Domain Admin or Mixed Domain Admin
-        if is_domain_admin(request):
+        is_domain_context_specified = bool(
+            request.session.get("domain_context"))
+
+        # If user is Cloud Admin, Domain Admin or Mixed Domain Admin and there
+        # is no domain context specified, use domain scoped token
+        if is_domain_admin(request) and not is_domain_context_specified:
             domain_token = request.session.get('domain_token')
             if domain_token:
                 token_id = getattr(domain_token, 'auth_token', None)
@@ -1003,12 +1007,14 @@ def application_credential_delete(request, application_credential_id):
 @profiler.trace
 def application_credential_create(request, name, secret=None,
                                   description=None, expires_at=None,
-                                  roles=None, unrestricted=False):
+                                  roles=None, unrestricted=False,
+                                  access_rules=None):
     user = request.user.id
     manager = keystoneclient(request).application_credentials
     try:
         return manager.create(name=name, user=user, secret=secret,
                               description=description, expires_at=expires_at,
-                              roles=roles, unrestricted=unrestricted)
+                              roles=roles, unrestricted=unrestricted,
+                              access_rules=access_rules)
     except keystone_exceptions.Conflict:
         raise exceptions.Conflict()
