@@ -77,38 +77,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         glance.Image().delete(request, "1")
         self.mock_image_delete.assert_called_once_with(request, "1")
 
-    @test.create_mocks({api.glance: ['image_update', 'VERSIONS']})
-    def test_image_edit_v1(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "aki", "container_format": "aki",
-            "visibility": "public", "protected": false,
-            "image_url": "test.com",
-            "source_type": "url", "architecture": "testArch",
-            "description": "description", "kernel": "kernel",
-            "min_disk": 10, "min_ram": 5, "ramdisk": 10 }
-        ''')
-        self.mock_VERSIONS.active = 1
-        self.mock_image_update.return_value = self.images.first()
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'aki',
-                    'container_format': 'aki',
-                    'is_public': True,
-                    'protected': False,
-                    'min_disk': 10,
-                    'min_ram': 5,
-                    'properties': {'description': 'description',
-                                   'architecture': 'testArch',
-                                   'ramdisk_id': 10,
-                                   'kernel_id': 'kernel'}
-                    }
-
-        response = glance.Image().patch(request, "1")
-        self.assertStatusCode(response, 204)
-        self.assertEqual(response.content.decode('utf-8'), '')
-        self.mock_image_update.assert_called_once_with(request, '1',
-                                                       **metadata)
-
     @test.create_mocks({api.glance: ['image_update', 'VERSIONS']})
     def test_image_edit_v2(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -166,43 +134,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
                                                               filters=filters,
                                                               **kwargs)
 
-    @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
-    def test_image_create_v1_basic(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "aki", "import_data": false,
-            "visibility": "public", "container_format": "aki",
-            "protected": false, "image_url": "test.com",
-            "source_type": "url", "architecture": "testArch",
-            "description": "description", "kernel": "kernel",
-            "min_disk": 10, "min_ram": 5, "ramdisk": 10 }
-        ''')
-        new = self.mock_image_create.return_value
-        self.mock_VERSIONS.active = 1
-        new.to_dict.return_value = {'name': 'testimage'}
-        new.name = 'testimage'
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'aki',
-                    'container_format': 'aki',
-                    'is_public': True,
-                    'protected': False,
-                    'min_disk': 10,
-                    'min_ram': 5,
-                    'location': 'test.com',
-                    'properties': {
-                        'description': 'description',
-                        'architecture': 'testArch',
-                        'ramdisk_id': 10,
-                        'kernel_id': 'kernel',
-                    }}
-
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 201)
-        self.assertEqual(response.content.decode('utf-8'),
-                         '{"name": "testimage"}')
-        self.assertEqual(response['location'], '/api/glance/images/testimage')
-        self.mock_image_create.assert_called_once_with(request, **metadata)
-
     @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
     def test_image_create_v2_basic(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -239,43 +170,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         self.assertEqual(response['location'], '/api/glance/images/testimage')
         self.mock_image_create.assert_called_once_with(request, **metadata)
 
-    @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
-    def test_image_create_v1_shared(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "aki", "import_data": false,
-            "visibility": "shared", "container_format": "aki",
-            "protected": false, "image_url": "test.com",
-            "source_type": "url", "architecture": "testArch",
-            "description": "description", "kernel": "kernel",
-            "min_disk": 10, "min_ram": 5, "ramdisk": 10 }
-        ''')
-        self.mock_VERSIONS.active = 1
-        new = self.mock_image_create.return_value
-        new.to_dict.return_value = {'name': 'testimage'}
-        new.name = 'testimage'
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'aki',
-                    'container_format': 'aki',
-                    'is_public': False,
-                    'protected': False,
-                    'min_disk': 10,
-                    'min_ram': 5,
-                    'location': 'test.com',
-                    'properties': {
-                        'description': 'description',
-                        'architecture': 'testArch',
-                        'ramdisk_id': 10,
-                        'kernel_id': 'kernel',
-                    }}
-
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 201)
-        self.assertEqual(response.content.decode('utf-8'),
-                         '{"name": "testimage"}')
-        self.assertEqual(response['location'], '/api/glance/images/testimage')
-        self.mock_image_create.assert_called_once_with(request, **metadata)
-
     @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
     def test_image_create_v2_shared(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -312,43 +206,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         self.assertEqual(response['location'], '/api/glance/images/testimage')
         self.mock_image_create.assert_called_once_with(request, **metadata)
 
-    @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
-    def test_image_create_v1_private(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "aki", "import_data": false,
-            "visibility": "private", "container_format": "aki",
-            "protected": false, "image_url": "test.com",
-            "source_type": "url", "architecture": "testArch",
-            "description": "description", "kernel": "kernel",
-            "min_disk": 10, "min_ram": 5, "ramdisk": 10 }
-        ''')
-        self.mock_VERSIONS.active = 1
-        new = self.mock_image_create.return_value
-        new.to_dict.return_value = {'name': 'testimage'}
-        new.name = 'testimage'
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'aki',
-                    'container_format': 'aki',
-                    'is_public': False,
-                    'protected': False,
-                    'min_disk': 10,
-                    'min_ram': 5,
-                    'location': 'test.com',
-                    'properties': {
-                        'description': 'description',
-                        'architecture': 'testArch',
-                        'ramdisk_id': 10,
-                        'kernel_id': 'kernel',
-                    }}
-
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 201)
-        self.assertEqual(response.content.decode('utf-8'),
-                         '{"name": "testimage"}')
-        self.assertEqual(response['location'], '/api/glance/images/testimage')
-        self.mock_image_create.assert_called_once_with(request, **metadata)
-
     @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
     def test_image_create_v2_private(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -385,23 +242,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         self.assertEqual(response['location'], '/api/glance/images/testimage')
         self.mock_image_create.assert_called_once_with(request, **metadata)
 
-    @test.create_mocks({api.glance: ['VERSIONS']})
-    def test_image_create_v1_bad_visibility(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "aki", "import_data": false,
-            "visibility": "verybad", "container_format": "aki",
-            "protected": false, "image_url": "test.com",
-            "source_type": "url", "architecture": "testArch",
-            "description": "description", "kernel": "kernel",
-            "min_disk": 10, "min_ram": 5, "ramdisk": 10 }
-        ''')
-        self.mock_VERSIONS.active = 1
-
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 400)
-        self.assertEqual(response.content.decode('utf-8'),
-                         '"invalid visibility option: verybad"')
-
     @test.create_mocks({api.glance: ['VERSIONS']})
     def test_image_create_v2_bad_visibility(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -419,33 +259,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         self.assertEqual(response.content.decode('utf-8'),
                          '"invalid visibility option: verybad"')
 
-    @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
-    def test_image_create_v1_required(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "raw", "import_data": true,
-            "container_format": "docker",
-            "visibility": "public", "protected": false,
-            "source_type": "url", "image_url": "test.com" }''')
-        self.mock_VERSIONS.active = 1
-        new = self.mock_image_create.return_value
-        new.to_dict.return_value = {'name': 'testimage'}
-        new.name = 'testimage'
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'raw',
-                    'container_format': 'docker',
-                    'copy_from': 'test.com',
-                    'is_public': True,
-                    'protected': False,
-                    'min_disk': 0,
-                    'min_ram': 0,
-                    'properties': {}
-                    }
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 201)
-        self.assertEqual(response['location'], '/api/glance/images/testimage')
-        self.mock_image_create.assert_called_once_with(request, **metadata)
-
     @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
     def test_image_create_v2_required(self):
         request = self.mock_rest_request(body='''{"name": "Test",
@@ -472,34 +285,6 @@ class ImagesRestTestCase(test.ResetImageAPIVersionMixin, test.TestCase):
         self.assertEqual(response['location'], '/api/glance/images/testimage')
         self.mock_image_create.assert_called_once_with(request, **metadata)
 
-    @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
-    def test_image_create_v1_additional_props(self):
-        request = self.mock_rest_request(body='''{"name": "Test",
-            "disk_format": "raw", "import_data": true,
-            "container_format": "docker",
-            "visibility": "public", "protected": false,
-            "arbitrary": "property", "another": "prop",
-            "source_type": "url", "image_url": "test.com" }''')
-        self.mock_VERSIONS.active = 1
-        new = self.mock_image_create.return_value
-        new.to_dict.return_value = {'name': 'testimage'}
-        new.name = 'testimage'
-
-        metadata = {'name': 'Test',
-                    'disk_format': 'raw',
-                    'container_format': 'docker',
-                    'copy_from': 'test.com',
-                    'is_public': True,
-                    'protected': False,
-                    'min_disk': 0,
-                    'min_ram': 0,
-                    'properties': {'arbitrary': 'property', 'another': 'prop'}
-                    }
-        response = glance.Images().put(request)
-        self.assertStatusCode(response, 201)
-        self.assertEqual(response['location'], '/api/glance/images/testimage')
-        self.mock_image_create.assert_called_once_with(request, **metadata)
-
     @test.create_mocks({api.glance: ['image_create', 'VERSIONS']})
     def test_image_create_v2_additional_props(self):
         request = self.mock_rest_request(body='''{"name": "Test",
